# Installation Instructions

[[_TOC_]]

## 1. General remarks

The installation instructions will use the following environment variables

- `WM_PROJECT_DIR`: source code of the OpenFOAM Foundation Software [^2]
- `WM_PROJECT_SITE`: addon source code
- `WM_PROJECT_VERSION`: version of OpenFOAM Foundation Software[^2],
  e.g., dev, 6, 9, 10-s.2

## 2. Option 1: Installation of Debian Packages

A debian packages is provided for Ubuntu Jammy Jellyfish (22.04) or newer. For
installation download the package from `Packages & Registries`[^1] menu and run

```shell
sudo apt update
sudo apt install ./multiphase-code-repository-by-hzdr-10-s.2-hzdr.2-amd64.deb
```

once the installation is finished add

```shell
source /opt/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=/opt/OpenFOAM/site
```

to your `~/.bashrc`.

Optionally, install Paraview

```shell
sudo apt install paraview
```

and use

```shell
paraFoam -builtin
```

to run Paraview.

## 3. Option 2: Compiling from sources

### 3.1. Prerequisites and Source Code of OpenFOAM Foundation Software

To compile the source code in the repository an installation of the software
released by the OpenFOAM Foundation[^2] is required. The required source code is
available at the OpenFOAM-dev[^3] repository at GitHub.

Note, if you have downloaded the source code from Rossendorf Data Repository
(RODARE) an archive with the required commit of the software released by the
OpenFOAM Foundation is available for download. Obtaining the source code from
GitHub or the provided archive is equal, instead of cloning the repository
unpack the archive to the required folder and follow the instructions.

On an Ubuntu Linux system install the following packages

```shell
sudo apt install build-essential flex bison git-core cmake zlib1g-dev \
     libboost-system-dev libboost-thread-dev libopenmpi-dev openmpi-bin \
     gnuplot libreadline-dev libncurses-dev libxt-dev ca-certificates libfl-dev
```

Create and enter a new directory

```shell
mkdir -p $HOME/OpenFOAM
cd $HOME/OpenFOAM
```

Now, clone the ThirdParty repository from GitHub and reset it to the required
commit sha

```shell
git clone https://github.com/OpenFOAM/ThirdParty-dev.git ThirdParty-10-s.2
(cd ThirdParty-10-s.2 && git reset --hard 167de219e6bdafb30c9067465b6ca35c1fd49e0e)
```

The same has to be done for the OpenFOAM-dev repository; clone it from GitHub
and reset to the required commit sha

```shell
git clone https://github.com/OpenFOAM/OpenFOAM-dev.git OpenFOAM-10-s.2
(cd OpenFOAM-10-s.2 && git reset --hard d558e493364cb716b827b75de2997d0430e6fda2)
```

Once all repositories are successfully cloned and reset, configure and load
the software environment

```shell
sed -i -e "s/\(WM_PROJECT_VERSION=\).*$/\110-s.2/" OpenFOAM-10-s.2/etc/bashrc
sed -i -e "s/\(WM_PROJECT_VERSION \).*$/\110-s.2/" OpenFOAM-10-s.2/etc/cshrc
source $HOME/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=~/OpenFOAM/site
```

**Mac OS:** As a default Mac OS uses the Apple File System (APFS) and this is
not case-sensitive. Before cloning any source code a new volume with
case-sensitive APFS is required[^16].

### 3.2. Prerequisites and Source Code for Addon

The source code can be obtained via:

- **Helmholtz Code Base**[^1]: For Helmholtz and Friends via Helmholtz AAI[^5]
  or using a HZDR guest account
- **Rossendorf Data Repository (RODARE)**[^6]: For everybody

For usage of the GPU (graphic processor unit) accelerated population balance
method a NVIDIA GPU with CUDA support is required as well as an installation of
the NVIDIA Cuda Toolkit[^4] with the NVCC compiler.

On an Ubuntu Linux system the following additional packages are required

```shell
sudo apt install qt5-qmake qtchooser qtbase5-dev libqt5charts5-dev
```

#### 3.2.1 Source Code from Helmholtz Code Base

For cloning the source code, first add the public ssh key[^7] of your local
machine to your Gitlab account. The git repository includes content that is
versioned using `git-lfs`[^8] to store large binary files in the repository

```shell
sudo apt install git-lfs
```

Then create the directory for the addon and clone the source code

```shell
source $HOME/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=~/OpenFOAM/site
mkdir -p $WM_PROJECT_SITE/$WM_PROJECT_VERSION
git clone --single-branch git@codebase.helmholtz.cloud:fwdc/multiphase/code.git $WM_PROJECT_SITE/$WM_PROJECT_VERSION
```

#### 3.2.2. Source code from Rossendorf Data Repository (RODARE)

Download and extract the tar archive[^6] from RODARE into the addon directory

```shell
source $HOME/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=~/OpenFOAM/site
mkdir -p $WM_PROJECT_SITE/$WM_PROJECT_VERSION
tar -xzf multiphase-code-repository-by-hzdr-10-s.2.tgz -C $WM_PROJECT_SITE/$WM_PROJECT_VERSION
```


### 3.3 Compiling the Source Code

Firstly, apply the provided patches to the installation of the software released
by the OpenFOAM Foundation

```shell
source $HOME/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=~/OpenFOAM/site
cp $WM_PROJECT_SITE/$WM_PROJECT_VERSION/patches/*.sprint.tgz $WM_PROJECT_DIR
cd $WM_PROJECT_DIR
for f in *.sprint.tgz; do if [[ -f $f ]]; then tar xzf "$f"; fi; done
for f in *.sprint; do if [[ -f $f ]]; then git am "$f"; fi; done
rm -f *.sprint *.sprint.tgz
```

Secondly, compile the source code by

```shell
cd $WM_PROJECT_DIR
./Allwmake -j
```

Once the compilation process is finished successfully, reload the software
environment and test the installation

```shell
source $HOME/OpenFOAM/OpenFOAM-10-s.2/etc/bashrc WM_PROJECT_SITE=~/OpenFOAM/site
foamVersion
```

For more details concerning other Linux operating systems, additional software
packages or more read the installation instructions for OpenFOAM-dev from Source
Repository[^9].

Finally, compile the source code in the site directory

```shell
cd $WM_PROJECT_SITE/$WM_PROJECT_VERSION
./Allwmake -j
```

## 4. Option 3: Using Docker Images

Docker is a popular software for Operating-System-Level virtualisation and can
be used to deliver software in packages and a pre-defined environment. Those
packages are called Docker images and a running instance of such an image is
called a Docker container. Those containers are isolated from each other and
from the host system. For Helmholtz and Friends a ready-to-run installation is
provided as a Docker image. The Docker images in the corresponding Docker
registry[^1] feature support for graphical desktop applications, such as
Paraview. Supported are Intel and NVIDIA graphic cards, but currently no AMD
graphic cards.

### 4.1. Prerequisites

Follow the installation instructions for Docker and your operating system on the
Docker homepage[^10]. If the CUDA functionality is of interest, the Nvidia
Container Toolkit[^12] has to be installed.

### 4.2. Available Docker Images at Helmholtz Code Base

The project's docker registry[^1] contains images with a ready-to-run
installation.

| Docker image tag      | Platform | Display Server Support | Cuda | Compiler | Compile Option |
|-----------------------|----------|------------------------|------|----------|----------------|
| addonLinux64GccOpt    | x86_64   | :white_check_mark:     | :x:  | Gcc      | Optimised      |
| addonLinuxArm64GccOpt | arm64    | :white_check_mark:     | :x:  | Gcc      | Optimised      |

The source code of the OpenFOAM Foundation Software is installed inside the
docker image in `opt/OpenFOAM/` and the source code from this repository is
located in `/opt/OpenFOAM/site/10-s.2`.

#### 4.2.1. Launch image with Docker

Login to docker registry

```shell
docker login registry.hzdr.de
```

and launch container

```shell
docker run -it registry.hzdr.de/fwdc/multiphase/code/10-s.2:<image> bash
```

or with CUDA support

```shell
docker run -it --gpus all registry.hzdr.de/fwdc/multiphase/code/10-s.2:<image> bash
```

Note, you have to replace `<image>` with an
[image tag](#42-available-docker-images-at-helmholtz-code-base). The software
provided by the OpenFOAM Foundation requires a user, which is not `root` to be
used in the docker image for security reasons. Hence, the docker image used a
predefined user named `docker`. When binding volumes to the container, this can
cause conflicts with write permissions, as typically the id of the `docker` user
does not match the id of the host user. The only way to ensure consitent write
permissions is to build a custom docker image and add the host user, e.g.,

```docker
RUN groupadd -g "<gid>" "<groupname>" \
    && useradd -l -u "<uid>" -g "<groupname>" -m "<username>" -s "/bin/bash" \
    && echo "<username>" ALL=\(root\) NOPASSWD:ALL > "/etc/sudoers.d/<username>" \
    && chmod 0440 "/etc/sudoers.d/<username>"
```

The name and the id of the user and the group should match the host user and its
primary group. The corresponding values can be obtained by, e.g., `id -u`,
`id -un`, `id -g`, and `id -gn`.

#### 4.2.2. Launch image with mpydocker

For a more comfortable usage a script `mpydocker` is provided with the
`multiphasepy` package[^17]. The package can be installed via

```shell
pip install multiphasepy --index-url https://codebase.helmholtz.cloud/api/v4/projects/8786/packages/pypi/simple
```
For more information and options run `mpydocker --help`.

## 5. Option 4: Building Docker Images

The required `Dockerfile` for building the Docker images is available in
`etc/docker`. The `Dockerfile` is a multi-stage `Dockerfile` with
the following stages:

- **ubuntu:** operation system and required packages
- **openmpi:** communication libaries
- **paraview:** visualisation toolkit
- **openfoam:** image for OpenFOAM Foundation Software
- **addon:** source code for Multiphase Code Repository by HZDR
- **python:** multiphasepy package with python code and dependencies
- **final:** final configuration for deployment

### 5.1. Building with Docker

For building the Docker images use the following command

```shell
docker build --tag <image> -f etc/docker/Dockerfile .
```

The image can be modified with docker build arguments. The available variables
for  `--build-arg` are defined by the `Dockerfile` and the default options are
listed in the following table. It is possible to build the image only to a
certain stage by using the option `--target <stage>`.

| Name                 | Default                                        | Options                         | Description                             |
|----------------------|------------------------------------------------|---------------------------------|-----------------------------------------|
| FROMIMAGE            | ubuntu:22.04                                   | cudagl:12.2.0-devel-ubuntu22.04 | Base image with operating system        |
| OPENFOAM_ROOT        | /opt/OpenFOAM                                  | -                               | Installation path                       |
| WM_PROJECT_VERSION   | 10-s.2                                         | dev                             | Version of OpenFOAM Foundation software |
| WM_COMPILE_OPTION    | Opt                                            | Debug, Prof                     | Compile option                          |
| WM_PROJECT           | OpenFOAM                                       | -                               | Name of the project                     |
| WM_COMPILER          | Gcc                                            | -                               | Compiler                                |
| WM_ARCH              | linux64                                        | linuxArm64                      | Compiler Platform                       |
| WM_CC                | gcc                                            | -                               | Thirdparty C compiler                   |
| WM_CFLAGS            | -m64 -fPIC                                     | -fPIC                           | Thirdparty C compiler flags             |
| WM_COMPILER_LIB_ARCH | 64                                             | -                               | Thirdparty compiler architecture        |
| WM_CXX               | g++                                            | -                               | Thirdparty Cpp compiler                 |
| WM_CXXFLAGS          | -m64 -fPIC -std=c++0x                          | -fPIC -std=c++0x                | Thirdparty Cpp compiler flags           |
| WM_LDFLAGS           | -m64                                           | -                               | Thirdparty flags for linking            |
| OFREPOSITORY         | <https://github.com/OpenFOAM/OpenFOAM-dev.git> | -                               | Url for OpenFOAM-dev git repository     |
| WM_PROJECT_COMMIT    | d558e493364cb716b827b75de2997d0430e6fda2       | HEAD                            | Valid Git commit sha for OpenFOAM-dev   |
| PARAVIEW             | No                                             | Yes                             | Build Paraview                          |
| PARAVIEW_ROOT        | /opt/paraview                                  | -                               | Installation path for Paraview          |
| PARAVIEW_VERSION     | 5.11.1                                         | -                               | Paraview version                        |
| LIBFABRIC_VERSION    | 1.15.2                                         | -                               | Libfabric library version               |
| OMPI_VERSION         | 4.0.4                                          | -                               | OpenMPI library version                 |
| USERNAME             | docker                                         | -                               | Default user name in docker container   |
| GROUPNAME            | docker                                         | -                               | Default group name in docker container  |
| USERID               | 1000                                           | -                               | Default user id in docker container     |
| GROUPID              | 1000                                           | -                               | Default group id in docker container    |

### 5.3. Customised Docker image

Additional software like editors or graphical diff tools are not installed as
default to keep the size of the Docker images small. If additional software
packages are required, the Docker images can be customised. The most comfortable
way is to use `mpydocker`, which allows to define build instructions for
building a customised docker image in its configuration file. Use
`mpydocker --help` and `mpydocker --print_config` for more information. As an
alternative it is always possible to create your own `Dockerfile`[^15], with
the required additional packages and build it with `docker build`.

---
[^1]: <https://codebase.helmholtz.cloud/fwdc/multiphase/code>
[^2]: <https://openfoam.org>
[^3]: <https://github.com/OpenFOAM/OpenFOAM-dev>
[^4]: <https://developer.nvidia.com/cuda-toolkit>
[^5]: <https://aai.helmholtz.de>
[^6]: <https://doi.org/10.14278/rodare.767>
[^7]: <https://docs.gitlab.com/ee/user/ssh.html>
[^8]: <https://git-lfs.github.com>
[^9]: <https://openfoam.org/download/source/>
[^10]: <https://docs.docker.com/engine/installation>
[^12]: <https://github.com/NVIDIA/nvidia-docker>
[^15]: <https://docs.docker.com/engine/reference/builder>
[^16]: <https://support.apple.com/guide/disk-utility>
[^17]: <https://codebase.helmholtz.cloud/fwdc/python>
