# README for Multiphase Code Repository by HZDR

[[_TOC_]]

## Multiphase Code Repository by HZDR

The Multiphase Code Repository by HZDR is a software publication released by
Helmholtz-Zentrum Dresden-Rossendorf according to the FAIR principles[^1]
(Findability, Accessibility, Interoperability, and Reuseability). It contains
experimental research work for the open-source software released by
the OpenFOAM Foundation[^2]. The developments are dedicated to the numerical
simulation of multiphase flows, in particular to the multi-field two-fluid model
(Euler-Euler method).

**Acknowledgement:** OpenFOAM(R) is a registered trade mark of OpenCFD Limited,
producer and distributor of the OpenFOAM(R) software via
[www.openfoam.com](https://openfoam.com). The Multiphase Code Repository by HZDR
is not compatible with the software released by OpenCFD Limited, but is based on
the software released by the OpenFOAM Foundation via
[www.openfoam.org](https://openfoam.org).

## Highlights of the Multiphase Code Repository by HZDR

For more information refer to <https://www.hzdr.de/db/Cms?pOid=50526>.

### Baseline Model by HZDR

The _addonMultiphaseEuler_ solver with full support of the baseline
model developed by HZDR [^3] for polydisperse bubbly flows, including
configuration files and tutorials for simplified setup of cases
(Hänsch et al., 2021)[^10].

### Population Balance Modelling

A GPU-accelerated population balance method [^4] according to
Petelin et al. (2021)[^12].

### Morphology-adaptive Multifield Two-fluid Model (MultiMorph Model)

The _cipsaMultiphaseEuler_ solver featuring a morphology-adaptive modelling
approach[^5] (dispersed and resolved interfaces, Meller et al., 2021)[^11] with
an interface to the _multiphaseEuler_ framework to utilise all available
interfacial models, and configuration files and tutorials for easy setup of
cases with the MultiMorph Model.

## Installation

Refer to the [INSTALLATION.md] in the repository[^6].

## Sprint Cycle Development

The software development is based on sprint cycles of the software releases by
OpenFOAM Foundation. The sprint version number is constructed according to
semantic versioning[^7] as follows:

- **first digit** represents stable release of the OpenFOAM Foundation software
- **s** is an abbreviation for sprint cycle
- **last digit** represents the current sprint cycle with respect to the first digit

| WM_PROJECT_VERSION | WM_PROJECT_COMMIT                                                                                   | THIRDPARTY_COMMIT                                                                                     |
|--------------------|-----------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------|
| 10-s.2             | [d558e49](https://github.com/OpenFOAM/OpenFOAM-dev/commit/d558e493364cb716b827b75de2997d0430e6fda2) | [167de21](https://github.com/OpenFOAM/ThirdParty-dev/commit/167de219e6bdafb30c9067465b6ca35c1fd49e0e)
| 10-s.1             | [3805586](https://github.com/OpenFOAM/OpenFOAM-dev/commit/380558649e1feb5355d746a50f73d22b6fda5e3c) | [1aa9e08](https://github.com/OpenFOAM/ThirdParty-dev/commit/1aa9e0871798ee3deb69ea59235fcd2ec2a26736) |
| 9-s.1              | [01f0753](https://github.com/OpenFOAM/OpenFOAM-dev/commit/01f0753ac7bafff1c39df37b5259adf4df2f380e) | [588fb48](https://github.com/OpenFOAM/ThirdParty-dev/commit/588fb48a605b80819d371735fba4de2aa3d69ae6) |
| 8-s.5              | [28745ec](https://github.com/OpenFOAM/OpenFOAM-dev/commit/28745eca4bfb86de99f419278445fc882838d921) | [c53f2db](https://github.com/OpenFOAM/ThirdParty-dev/commit/c53f2dbf37177dec40a2056df9111608883da7c0) |
| 8-s.4              | [de9b29f](https://github.com/OpenFOAM/OpenFOAM-dev/commit/de9b29f0fdbb176cc31b8d466f60be3f4fb934de) | [c53f2db](https://github.com/OpenFOAM/ThirdParty-dev/commit/c53f2dbf37177dec40a2056df9111608883da7c0) |
| 8-s.3              | [1e728ad](https://github.com/OpenFOAM/OpenFOAM-dev/commit/1e728ad7e301d6656158f6cbde706bea6c559344) | [c53f2db](https://github.com/OpenFOAM/ThirdParty-dev/commit/c53f2dbf37177dec40a2056df9111608883da7c0) |
| 8-s.2              | [85f0430](https://github.com/OpenFOAM/OpenFOAM-dev/commit/85f043040b169bf0510f4408066387d343c25502) | [c53f2db](https://github.com/OpenFOAM/ThirdParty-dev/commit/c53f2dbf37177dec40a2056df9111608883da7c0) |
| 8-s.1              | [20ce929](https://github.com/OpenFOAM/OpenFOAM-dev/commit/20ce9298d23f8bd15ebd6fe8e1036b84616e5a26) | [c53f2db](https://github.com/OpenFOAM/ThirdParty-dev/commit/c53f2dbf37177dec40a2056df9111608883da7c0) |
| 7-s.2              | [7dd592f](https://github.com/OpenFOAM/OpenFOAM-dev/commit/7dd592ff4013fc6e444f27b12ff8729774cb5e0f) | [f83b1b6](https://github.com/OpenFOAM/ThirdParty-dev/commit/f83b1b65b48f3ac35ca69677e392ce78315095ae) |
| 7-s.1              | [375e1f7](https://github.com/OpenFOAM/OpenFOAM-dev/commit/375e1f7c63fff4bc0702e5272353c99dc7eb1ed2) | [f53c0b4](https://github.com/OpenFOAM/ThirdParty-dev/commit/f53c0b4c828633b93060c15144f95a032b1c5a08) |
| 6-s.2              | [e407f7d](https://github.com/OpenFOAM/OpenFOAM-dev/commit/e407f7dcb73e31c0dee90b0beb00c5f41d4db3d9) | [f53c0b4](https://github.com/OpenFOAM/ThirdParty-dev/commit/f53c0b4c828633b93060c15144f95a032b1c5a08) |
| 6-s.1              | [8c152cb](https://github.com/OpenFOAM/OpenFOAM-dev/commit/8c152cbc38a6f23f09254249c67470d5d1c6e946) | [f53c0b4](https://github.com/OpenFOAM/ThirdParty-dev/commit/f53c0b4c828633b93060c15144f95a032b1c5a08) |

## Repository Structure

The repository includes the following main directories and files:

| Directory          | Description                                                      |
|--------------------|------------------------------------------------------------------|
| applications       | additional solvers and applications                              |
| etc                | configuration files and various templates                        |
| test               | modified test/tutorial cases from release to check functionality |
| testAddon          | additional test cases to check functionality                     |
| testCuda           | test cases to check NVIDIA CUDA functionality                    |
| tutorials          | modified demonstration cases from release                        |
| tutorialsAddon     | additional demonstration cases                                   |
| tutorialsCuda      | demonstration cases using NVIDIA CUDA                            |
| src                | additional source code                                           |
| .editorconfig      | editor configuration[^8] for code style                          |
| codemeta.json      | software metadata[^9]                                            |
| CONTRIBUTING.md    | how to contribute to the project                                 |
| INSTALLATION.md    | detailed installation instructions                               |
| LICENSE            | licensing information                                            |

## How to cite us?

When using the Multiphase Code Repository by HZDR cite as

>>>
Schlegel, F., Bilde, K., Draw, M., Evdokimov, I., Hänsch, S., Kamble, V., Khan,
H., Krull, B., Lehnigk, R., Li, J., Lyu, H., Meller, R., Petelin, G., Kota, S.,
Tekavcic, M. (2024). Multiphase Code Repository by HZDR for OpenFOAM Foundation
Software. Rodare. <https://doi.org/10.14278/rodare.767>.
>>>

## Links and References

[^1]: <https://www.go-fair.org/fair-principles>
[^2]: <http://www.openfoam.org>
[^3]: <https://www.hzdr.de/db/Cms?pOid=50671>
[^4]: <https://www.hzdr.de/db/Cms?pOid=65155>
[^5]: <https://hzdr.de/multimorph>
[^6]: <https://codebase.helmholtz.cloud/fwdc/multiphase/code>
[^7]: <https://semver.org>
[^8]: <https://editorconfig.org>
[^9]: <https://codemeta.github.io>
[^10]: Hänsch, S., Evdokimov, I., Schlegel, F., & Lucas, D. (2021). A workflow for the sustainable development of closure models for bubbly flows. Chemical Engineering Science, 116807.
[^11]: Meller, R., Schlegel, F., & Lucas, D. (2021). Basic verification of a numerical framework applied to a morphology adaptive multifield two‐fluid model considering bubble motions. International Journal for Numerical Methods in Fluids, 93(3), 748-773.
[^12]: Petelin, G., Lehnigk, R., Kelling, J., Papa, G., & Schlegel, F. (2021). GPU-based Accelerated Computation of Coalescence and Breakup Frequencies for Polydisperse Bubbly Flows. 30th International Conference Nuclear Energy for New Europe (NENE2021), Bled, Slovenia.
