/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::liftModels::SaffmanMei

Description
    Lift model of Saffman (1965) as extended by Mei (1992). Applicable to
    spherical particles.

    References:
    \verbatim
        Saffman, P. G. T. (1965).
        The lift on a small sphere in a slow shear flow.
        Journal of fluid mechanics, 22(2), 385-400.

        Mei, R. (1992).
        An approximate expression for the shear lift force on a spherical
        particle at finite Reynolds number.
        International Journal of Multiphase Flow, 18(1), 145-147.
    \endverbatim

SourceFiles
    SaffmanMei.C

\*---------------------------------------------------------------------------*/

#ifndef SaffmanMei_H
#define SaffmanMei_H

#include "dispersedLiftModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace liftModels
{

/*---------------------------------------------------------------------------*\
                         Class SaffmanMei Declaration
\*---------------------------------------------------------------------------*/

class SaffmanMei
:
    public dispersedLiftModel
{
    // Private Data

        //- Residual Reynold's number
        const dimensionedScalar residualRe_;


public:

    //- Runtime type information
    TypeName("SaffmanMei");


    // Constructors

        //- Construct from a dictionary and an interface
        SaffmanMei
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~SaffmanMei();


    // Member Functions

        //- Lift coefficient
        virtual tmp<volScalarField> Cl() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace liftModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
