/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::constantRate

Description
    Phase transfer model converting a dispersed phase to a continuous one at a
    specified rate.

    Example usage:
    \verbatim
    phaseTransfer
    {
        phase1_dispersedIn_phase2
        {
            type            constantRate;
            rate            100;
        }
    }
    \endverbatim

SourceFiles
    constantRate.C

\*---------------------------------------------------------------------------*/

#ifndef constantRate_H
#define constantRate_H

#include "phaseTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                         Class constantRate Declaration
\*---------------------------------------------------------------------------*/

class constantRate
:
    public phaseTransferModel
{
private:

    // Private Data

        //- Interface
        const phaseInterface interface_;

        //- The constantRate efficiency
        const dimensionedScalar rate_;


public:

    //- Runtime type information
    TypeName("constantRate");


    // Constructors

        //- Construct from a dictionary and an interface
        constantRate
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~constantRate();


    // Member Functions

        //- Whether or not there is a mass transfer rate for the mixture
        virtual bool mixture() const;

        //- The mass transfer rate for the mixture
        virtual tmp<volScalarField> dmdtf() const;

        //- The mass transfer rate derivative w.r.t pressure for the mixture
        virtual tmp<volScalarField> d2mdtdpf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //