/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::disintegrationToDisperse

Description
    Morphology transfer model representing change from a under-resolved
    continuous phase to a disperse phase. The dominant continuous phase is
    locally excluded from this transfer. Furthermore, a minimal local sum of all
    continuous phases is required to increase numerical stability.

Usage
    \table
        Property           | Description                   | Required | Default
        continuousThreshold|Minimal required sum of continuous phases| no| 0.5
    \endtable

See also
    Foam::phaseTransferModels::morphologyTransferModel

SourceFiles
    disintegrationToDisperse.C

\*---------------------------------------------------------------------------*/

#ifndef disintegrationToDisperse_H
#define disintegrationToDisperse_H

#include "morphologyTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                   Class disintegrationToDisperse Declaration
\*---------------------------------------------------------------------------*/

class disintegrationToDisperse
:
    public morphologyTransferModel
{
    // Private Data

        //- Continuous member of phase pair
        const phaseModel& pairContinuous_;

        //- Threshold of sum of continuous phases to activate transfer
        const scalar contThreshold_;


public:

    //- Runtime type information
    TypeName("disintegrationToDisperse");


    // Constructors

        //- Construct from components
        disintegrationToDisperse
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~disintegrationToDisperse();


    // Member Functions

        //- The mass transfer rate for the mixture
        virtual tmp<volScalarField> dmdtf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
