/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::morphologyTransferModel

Description
    Abstract base class for morphology transfer models between continuous and
    disperse phases. The convention is to use an ordered phase pair of the
    structure "(phase1 in phase2)", where mass is transferred from phase1
    towards phase2.

Usage
    \table
        Property       | Description                        | Required | Default
        timeScale      | Characteristic phase transfer time | no       | 0.01 s
    \endtable

SourceFiles
    morphologyTransferModel.C

\*---------------------------------------------------------------------------*/

#ifndef morphologyTransferModel_H
#define morphologyTransferModel_H

#include "phaseTransferModel.H"
#include "dispersedPhaseInterface.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                   Class morphologyTransferModel Declaration
\*---------------------------------------------------------------------------*/

class morphologyTransferModel
:
    public phaseTransferModel
{
protected:

    // Protected Data

        //- Interface
        const dispersedPhaseInterface interface_;

        //- Phase transfer time scale
        const dimensionedScalar timeScale_;


    // Protected Member Functions

        //- Return rate
        virtual tmp<volScalarField> rate(const phaseModel&) const;


public:

    //- Runtime type information
    TypeName("morphologyTransferModel");


    // Constructors

        //- Construct from components
        morphologyTransferModel
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~morphologyTransferModel();


    // Member Functions

        //- Whether or not there is a mass transfer rate for the mixture
        virtual bool mixture() const;

        //- The mass transfer rate for the mixture
        virtual tmp<volScalarField> dmdtf() const = 0;

        //- The mass transfer rate derivative w.r.t pressure for the mixture
        virtual tmp<volScalarField> d2mdtdpf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
