/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::phaseTransferModels::reactionDriven

Description
    Phase transfer model representing change from one phase to another due
    to reactions. Intended for irreversible reactions.

SourceFiles
    reactionDriven.C

\*---------------------------------------------------------------------------*/

#ifndef reactionDriven_H
#define reactionDriven_H

#include "phaseTransferModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace phaseTransferModels
{

/*---------------------------------------------------------------------------*\
                       Class reactionDriven Declaration
\*---------------------------------------------------------------------------*/

class reactionDriven
:
    public phaseTransferModel
{
private:

    // Private Data

        //- Interface
        const phaseInterface interface_;

        //- The name of the phase where the reactions occur
        const word reactingName_;

        //- Const reference to the reacting phase
        const phaseModel& reactingPhase_;

        //- Const reference to the other phase
        const phaseModel& otherPhase_;

        //- Sign used to multiply the source terms
        const scalar sign_;

        //- List of species changing phase
        const hashedWordList species_;


public:

    //- Runtime type information
    TypeName("reactionDriven");


    // Constructors

        //- Construct from a dictionary and an interface
        reactionDriven
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~reactionDriven();


    // Member Functions

        //- The list of individual species that are transferred
        virtual const hashedWordList& species() const;

        //- The mass transfer rate for individual species
        virtual HashPtrTable<volScalarField> dmidtf() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace phaseTransferModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
