/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::swarmCorrections::Garnier

Description
    Swarm correction of Garnier et al.

    Reference:
    \verbatim
        Garnier, C., Lance, M., & Marie, J. L. (2002).
        Measurement of local flow characteristics in buoyancy-driven bubbly flow
        at high void fraction.
        Experimental Thermal and Fluid Science, 26, 811-815.
    \endverbatim

    Note: A constant coefficient (CAlpha), which defaults to 1, is added to the
    correlation to allow some degree of user-defined modification.

SourceFiles
    Garnier.C

\*---------------------------------------------------------------------------*/

#ifndef Garnier_H
#define Garnier_H

#include "swarmCorrection.H"
#include "dispersedPhaseInterface.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace swarmCorrections
{

/*---------------------------------------------------------------------------*\
                           Class Garnier Declaration
\*---------------------------------------------------------------------------*/

class Garnier
:
    public swarmCorrection
{
    // Private Data

        //- Residual phase fraction
        const dimensionedScalar residualAlpha_;

        //- Constant coefficient
        const dimensionedScalar CAlpha_;


public:

    //- Runtime type information
    TypeName("Garnier");


    // Constructors

        //- Construct from a dictionary and an interface
        Garnier
        (
            const dictionary& dict,
            const phaseInterface& interface
        );


    //- Destructor
    virtual ~Garnier();


    // Member Functions

        //- Swarm correction coefficient
        virtual tmp<volScalarField> Cs() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace swarmCorrections
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
