/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::virtualMassModels::wallDampedVirtualMass

Description
    Wall-damped virtual mass model.
    Ongoing and unpublished work related to wall damping by Rzehak et al.

SourceFiles
    wallDampedVirtualMass.C

\*---------------------------------------------------------------------------*/

#ifndef wallDampedVirtualMass_H
#define wallDampedVirtualMass_H

#include "dispersedVirtualMassModel.H"
#include "wallDampingModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

namespace virtualMassModels
{

/*---------------------------------------------------------------------------*\
                    Class wallDampedVirtualMass Declaration
\*---------------------------------------------------------------------------*/

class wallDampedVirtualMass
:
    public dispersedVirtualMassModel
{
    // Private Data

        //- The virtual mass model to damp
        autoPtr<virtualMassModel> virtualMassModel_;

        //- The wall-damping model
        autoPtr<wallDampingModel> wallDampingModel_;


public:

    //- Runtime type information
    TypeName("wallDamped");


    // Constructors

        //- Construct from a dictionary and an interface
        wallDampedVirtualMass
        (
            const dictionary& dict,
            const phaseInterface& interface,
            const bool registerObject
        );


    //- Destructor
    virtual ~wallDampedVirtualMass();


    // Member Functions

        //- Return the virtual mass coefficient
        virtual tmp<volScalarField> Cvm() const;

        //- Return the phase-intensive virtual mass coefficient Ki
        //  used in the momentum equation
        virtual tmp<volScalarField> Ki() const;

        //- Return the virtual mass coefficient K
        //  used in the momentum equation
        virtual tmp<volScalarField> K() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace virtualMassModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
