/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2024 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2024 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "clusterTrackingModel.H"
#include "phaseSystem.H"
#include "addToRunTimeSelectionTable.H"

// Dummy type class to allow direct access to base class functionality
namespace Foam
{
namespace clusterTrackingModels
{
    class baseClusterTracking
    :
        public clusterTrackingModel
    {
    public:

        //- Runtime type information
        TypeName("base");


        // Constructors

            //- Construct from a dictionary and an interface
            baseClusterTracking
            (
                const dictionary& dict,
                const phaseInterface& interface
            )
            : clusterTrackingModel(dict, interface)
            {}


        //- Destructor
        virtual ~baseClusterTracking(){}
    };


    defineTypeNameAndDebug(baseClusterTracking, 0);
    addToRunTimeSelectionTable
    (
        clusterTrackingModel,
        baseClusterTracking,
        dictionary
    );
}
}

// * * * * * * * * * * * * * * * * Selector  * * * * * * * * * * * * * * * * //

Foam::autoPtr<Foam::clusterTrackingModel>
Foam::clusterTrackingModel::New
(
    const dictionary& dict,
    const phaseInterface& interface,
    const bool outer
)
{
    const dictionary& modelDict =
        outer
      ? interface.fluid().modelSubDict<clusterTrackingModel>(dict)
      : dict;

    word clusterTrackingModelType("base");

    Info<< "Creating clusterTrackingModel for "
        << interface.name() << ": " << clusterTrackingModelType
        << endl;

    dictionaryConstructorTable::iterator cstrIter =
        dictionaryConstructorTablePtr_->find
        (
            clusterTrackingModelType
        );

    if (cstrIter == dictionaryConstructorTablePtr_->end())
    {
        FatalErrorInFunction
            << "Unknown clusterTrackingModelType type "
            << clusterTrackingModelType << endl << endl
            << "Valid clusterTrackingModel types are : " << endl
            << dictionaryConstructorTablePtr_->sortedToc()
            << exit(FatalError);
    }

    return cstrIter()(modelDict, interface);
}


// ************************************************************************* //
