/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::surfaceTensionForceModels::noSurfaceTensionForce

Description
    Deactivated surface tension force.

SourceFiles
    noSurfaceTensionForce.C

\*---------------------------------------------------------------------------*/

#ifndef noSurfaceTensionForce_H
#define noSurfaceTensionForce_H

#include "surfaceTensionForceModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace surfaceTensionForceModels
{

/*---------------------------------------------------------------------------*\
                    Class noSurfaceTensionForce Declaration
\*---------------------------------------------------------------------------*/

class noSurfaceTensionForce
:
    public surfaceTensionForceModel
{
public:

    //- Runtime type information
    TypeName("none");


    // Constructors

        //- Construct from phaseSystem
        noSurfaceTensionForce(const phaseSystem& fluid);


    //- Destructor
    virtual ~noSurfaceTensionForce();


    // Member Functions

        //- Return the curvature of this interface
        virtual tmp<volScalarField> K
        (
            const segregatedPhaseInterface& interface
        ) const;

        //- Interface compression flux
        virtual tmp<surfaceScalarField> surfaceTensionForcef
        (
            const segregatedPhaseInterface& interface
        ) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace surfaceTensionForceModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
