/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::SidedInterfacialModel

Description

SourceFiles
    SidedInterfacialModel.C

\*---------------------------------------------------------------------------*/

#ifndef SidedInterfacialModel_H
#define SidedInterfacialModel_H

#include "phaseInterface.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                   Class SidedInterfacialModel Declaration
\*---------------------------------------------------------------------------*/

template<class ModelType>
class SidedInterfacialModel
:
    public regIOobject
{
    // Private Data

        //- The interface
        const phaseInterface interface_;

        //- Model for within phase 1
        autoPtr<ModelType> modelInPhase1_;

        //- Model for within phase 2
        autoPtr<ModelType> modelInPhase2_;


public:

    //- Runtime type information
    TypeName("SidedInterfacialModel");


    // Constructors

        //- Construct from a dictionary and an interface
        SidedInterfacialModel
        (
            const dictionary& dict,
            const phaseInterface& interface
        );

        //- Disallow default bitwise copy construction
        SidedInterfacialModel
        (
            const SidedInterfacialModel<ModelType>&
        ) = delete;


    //- Destructor
    ~SidedInterfacialModel();


    // Member Functions

        //- Access the interface
        const phaseInterface& interface() const;

        //- Does a model exist in the given phase?
        bool haveModelInThe(const phaseModel& phase) const;

        //- Access the model within the given phase
        const ModelType& modelInThe(const phaseModel& phase) const;

        //- Access the model within the given phase
        ModelType& modelInThe(const phaseModel& phase);

        //- Dummy write for regIOobject
        bool writeData(Ostream& os) const;


    // Member Operators

        //- Disallow default bitwise assignment
        void operator=(const SidedInterfacialModel<ModelType>&) = delete;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#define defineSidedInterfacialModelTypeNameAndDebug(ModelType, DebugSwitch)    \
                                                                               \
    defineTemplateTypeNameAndDebugWithName                                     \
    (                                                                          \
        SidedInterfacialModel<ModelType>,                                      \
        (                                                                      \
            word(SidedInterfacialModel<ModelType>::typeName_()) + "<"          \
          + ModelType::typeName + ">"                                          \
        ).c_str(),                                                             \
        DebugSwitch                                                            \
    );


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "SidedInterfacialModel.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
