/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Copyright (C) 2023 by VTT Technical Research Centre of Finland Ltd,
    Website: https://www.vttresearch.com

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::residualDiameter

Description
    A diameter model which switches form constant diameter to constant residual
    diameter when the volume fraction of the phase is below residualAlpha.

    A typical use case for this is to set a small residual diameter to prevent
    excessive phase velocities in regions where the phase volume fraction is
    small.

SourceFiles
    residualDiameter.C

\*---------------------------------------------------------------------------*/

#ifndef residualDiameter_H
#define residualDiameter_H

#include "sphericalDiameter.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{

/*---------------------------------------------------------------------------*\
                      Class residualDiameter Declaration
\*---------------------------------------------------------------------------*/

class residualDiameter
:
    public spherical
{
    // Private data

        //- The diameter used when the volume fraction is above residualAlpha
        dimensionedScalar d_;

        //- The diameter used when the volume fraction is below residualAlpha
        dimensionedScalar dResidual_;


public:

    //- Runtime type information
    TypeName("residualDiameter");


    // Constructors

        residualDiameter
        (
            const dictionary& diameterProperties,
            const phaseModel& phase
        );


    //- Destructor
    virtual ~residualDiameter();


    // Member Functions

        //- Get the diameter field
        virtual tmp<volScalarField> d() const;

        //- Read diameterProperties dictionary
        virtual bool read(const dictionary& diameterProperties);
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
