/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::sidedPhaseInterface

Description
    Class to represent a certain side of an interface between phases.

SourceFiles
    sidedPhaseInterface.C

\*---------------------------------------------------------------------------*/

#ifndef sidedPhaseInterface_H
#define sidedPhaseInterface_H

#include "phaseInterface.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                   Class sidedPhaseInterface Declaration
\*---------------------------------------------------------------------------*/

class sidedPhaseInterface
:
    virtual public phaseInterface
{
private:

    // Private Data

        //- Phase
        const phaseModel& phase_;


public:

    //- Runtime type information
    TypeName("sidedPhaseInterface");


    // Constructors

        //- Construct from phases
        sidedPhaseInterface
        (
            const phaseModel& phase,
            const phaseModel& otherPhase
        );

        //- Construct from fluid and name
        sidedPhaseInterface
        (
            const phaseSystem& fluid,
            const word& name
        );


    //- Destructor
    virtual ~sidedPhaseInterface();


    // Static Member Functions

        //- Return the separator that delimits this interface's name
        static word separator()
        {
            return "inThe";
        }


    // Member Functions

        //- Name
        virtual word name() const;


        // Access

            //- Phase on the this side of the interface
            const phaseModel& phase() const;

            //- Phase on the other side of the interface
            const phaseModel& otherPhase() const;

            //- Interface on the other side of the interface
            autoPtr<phaseInterface> otherInterface() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
