/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::binaryBreakupModels::CUDALehrMilliesMewesSupportModel

Description
    CUDA interface for the CUDALehrMilliesMewes breakup model
    implemented as a pimpl design patterns.

SourceFiles
    CUDALehrMilliesMewesSupportModel.C

\*---------------------------------------------------------------------------*/

#ifndef CUDALehrMilliesMewesSupportModel_H
#define CUDALehrMilliesMewesSupportModel_H

#include "OFMemoryManagedField.H"
#include <memory>
#include <vector>
#include "CUDAPopulationBalance.H"
using namespace std;

using namespace Foam::diameterModels::cudaUtilities;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace binaryBreakupModels
{

/*---------------------------------------------------------------------------*\
              Class CUDALehrMilliesMewesSupportModel Declaration
\*---------------------------------------------------------------------------*/

class CUDALehrMilliesMewesSupportModel
{
public:
    // Public forward declarations
    class CUDALehrMilliesMewesBinaryBreakupRunnerPimpl;

    struct CUDALehrMilliesMewesBinaryBreakupModelPimpl;

    // Constructor
    CUDALehrMilliesMewesSupportModel(int numStreams);

    //- Destructor
    ~CUDALehrMilliesMewesSupportModel();

    // Member Functions

        //- Calculate binary breakupRate
        void calculateBinaryBreakupRate
        (
            CUDAPopulationBalance popBal,
            int domainSize,
            std::vector<std::pair<int, int>> &pairs
        );

        //- Set values required by the model
        void setModelVariables
        (
            double SMALL
        );

        //- Get a field with results
        OFMemoryManagedField getBinaryBreakupRate
        (
            int i,
            int j
        );

private:
        //- Pimpl pattern implementation
        std::unique_ptr<CUDALehrMilliesMewesBinaryBreakupRunnerPimpl> pimpl;

};

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace binaryBreakupModels
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
