/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

Class
    Foam::diameterModels::binaryBreakupModels::powerLawUniformBinary

Description
    Powerlaw kernel with a uniform daughter size distribution.

SourceFiles
    powerLawUniformBinary.C

\*---------------------------------------------------------------------------*/

#ifndef powerLawUniformBinary_H
#define powerLawUniformBinary_H

#include "binaryBreakupModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace diameterModels
{
namespace binaryBreakupModels
{

/*---------------------------------------------------------------------------*\
                    Class powerLawUniformBinary Declaration
\*---------------------------------------------------------------------------*/

class powerLawUniformBinary
:
    public binaryBreakupModel
{
/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin Comment HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~*\
    // Private Data
\*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End Comment HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
protected:

    // Protected Data
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

        //- Power
        scalar power_;


public:

    //- Runtime type information
    TypeName("powerLawUniformBinary");

    // Constructor

        powerLawUniformBinary
        (
            const populationBalanceModel& popBal,
            const dictionary& dict
        );


    //- Destructor
    virtual ~powerLawUniformBinary()
    {}


    // Member Functions

        //- Add to binary breakupRate
        virtual void addToBinaryBreakupRate
        (
            volScalarField& binaryBreakupRate,
            const label i,
            const label j
        );
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace binaryBreakupModels
} // End namespace diameterModels
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
