#!/bin/bash
#---------------------------------*- sh -*-------------------------------------
# ==  == ====== ====   ====    |
#                   \\     ||  | Multiphase Code Repository by HZDR
# ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
# ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
# ==  == ====== ====   ==  ==  |
#------------------------------------------------------------------------------
# License
#     This file is part of the Multiphase Code Repository by HZDR.
#
#     Copyright (C) 2024 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
#     Website: https://hzdr.de
#
#     Multiphase Code Repository by HZDR is based on the free software for
#     computational fluid dynamics (CFD) from the OpenFOAM Foundation.
#     Copyright (C) 2024 by OpenFOAM Foundation, Website: https://openfoam.org
#
#     If you are interested in which files are original OpenFOAM Foundation
#     files, which OpenFOAM Foundation files were modified, and which files were
#     newly created, see FILES.md.
#
#     Multiphase Code Repository by HZDR is free software: you can redistribute
#     it and/or modify it under the terms of the GNU General Public License as
#     published by the Free Software Foundation, either version 3 of the
#     License, or (at your option) any later version.
#
#     Multiphase Code Repository by HZDR is distributed in the hope that it will
#     be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
#     Public License for more details.
#
#     You should have received a copy of the GNU General Public License along
#     with the Multiphase Code Repository by HZDR. If not, see
#     <http://www.gnu.org/licenses/>.
#
# Description
#   Update the values for WM_PROJECT_COMMIT, THIRDPARTY_COMMIT and
#   WM_PROJECT_VERSION and reset addon version in several configuration files
#
#------------------------------------------------------------------------------

PROGNAME=$(basename "$0")

usage() {
   while [ "$#" -ge 1 ]; do echo "$1"; shift; done
   cat<<USAGE

usage: $PROGNAME [OPTION] WM_PROJECT_COMMIT THIRDPARTY_COMMIT WM_PROJECT_VERSION

options:
  -help         this usage

* Update the values for WM_PROJECT_COMMIT, THIRDPARTY_COMMIT and WM_PROJECT_VERSION and reset version of code repository in several configuration files

USAGE
   exit 1
}

# parse options
while [ "$#" -gt 0 ]
do
   case "$1" in
   -h | -help)
      usage
      ;;
   -*)
      usage "Error: Invalid option '$1'"
      ;;
   *)
      break
      ;;
   esac
done

OLD_WM_PROJECT_COMMIT=$(jq '.targetProduct | .[] | select(.name == "OpenFOAM-dev") | .softwareVersion' codemeta.json | tr -d '"')
OLD_WM_PROJECT_COMMIT_SHORT=$(echo OLD_WM_PROJECT_COMMIT | cut -c1-7)
OLD_THIRDPARTY_COMMIT=$(jq '.targetProduct | .[] | select(.name == "ThirdParty-dev") | .softwareVersion' codemeta.json | tr -d '"')
OLD_WM_PROJECT_VERSION=$(grep WM_PROJECT_VERSION .env | cut -d= -f2 | tr -d '"')

NEW_WM_PROJECT_COMMIT="$1"
NEW_WM_PROJECT_COMMIT_SHORT=$(echo NEW_WM_PROJECT_COMMIT | cut -c1-7)
NEW_THIRDPARTY_COMMIT="$2"
NEW_WM_PROJECT_VERSION="$3"

if [ -z "$NEW_WM_PROJECT_COMMIT" ] || [ -z "$NEW_THIRDPARTY_COMMIT" ] || [ -z "$NEW_WM_PROJECT_VERSION" ]
then
    usage "Error: requires complete set of values for WM_PROJECT_VERSION, WM_PROJECT_COMMIT and THIRDPARTY_COMMIT"
fi

# WM_PROJECT_VERSION
files=".env .gitlab-ci.yml codemeta.json .copier-answers.yml etc/docker/Dockerfile"
for file in $files
do
    echo "Replacing ${OLD_WM_PROJECT_VERSION} with ${NEW_WM_PROJECT_VERSION} in $file"
    sed -i "s/${OLD_WM_PROJECT_VERSION}/${NEW_WM_PROJECT_VERSION}/g" "$file"
done

# Addon version reset
files="codemeta.json"
for file in $files
do
    echo "Resetting addon version to hzdr-1 in $file"
    sed -i "s/${NEW_WM_PROJECT_VERSION}-hzdr.*\"/${NEW_WM_PROJECT_VERSION}-hzdr.1\"/g" "$file"
done

# WM_PROJECT_COMMIT
files=".env README.md codemeta.json .copier-answers.yml etc/docker/Dockerfile"
for file in $files
do
    echo "Replacing ${OLD_WM_PROJECT_COMMIT} with ${NEW_WM_PROJECT_COMMIT} in $file"
    sed -i "s/${OLD_WM_PROJECT_COMMIT}/${NEW_WM_PROJECT_COMMIT}/g" "$file"
done

# WM_PROJECT_COMMIT, short SHA
files="README.md"
for file in $files
do
    echo "Replacing ${OLD_WM_PROJECT_COMMIT_SHORT} with ${NEW_WM_PROJECT_COMMIT_SHORT} in $file"
    sed -i "s/${OLD_WM_PROJECT_COMMIT_SHORT}/${NEW_WM_PROJECT_COMMIT_SHORT}/g" "$file"
done

# THIRDPARTY_COMMIT
files=".env README.md codemeta.json .copier-answers.yml"
for file in $files
do
    echo "Replacing ${OLD_THIRDPARTY_COMMIT} with ${NEW_THIRDPARTY_COMMIT} in $file"
    sed -i "s/${OLD_THIRDPARTY_COMMIT}/${NEW_THIRDPARTY_COMMIT}/g" "$file"
done

# Copyright date
year=$(date +%Y)
find "$PWD" -type f -exec sed -i -E "s/Copyright \(C\) [0-9]*/Copyright (C) $year/g" {} \;

#------------------------------------------------------------------------------
