/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "volFields.H"

// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

template<class fieldType>
Foam::tmp<Foam::volScalarField>
Foam::fvc::spreadInterface
(
    fieldType& field,
    const volScalarField& alpha,
    const label nLayers,
    const scalar alphaDiff
)
{
    const fvMesh& mesh = field.mesh();

    const labelUList& owner = mesh.owner();
    const labelUList& neighbour = mesh.neighbour();

    tmp<volScalarField> infoLocation
    (
        new volScalarField
        (
            IOobject
            (
                "infoLocation",
                mesh.time().name(),
                mesh
            ),
            mesh,
            dimensionedScalar(dimless, Zero)
        )
    );

    volScalarField alphaInfo(alpha);

    volScalarField generation
    (
        IOobject
        (
            "generation",
            mesh.time().name(),
            mesh
        ),
        mesh,
        dimensionedScalar(dimless, Zero)
    );

    for (int i=0; i<nLayers; i++)
    {
        const fieldType field0(field);
        const volScalarField alphaInfo0(alphaInfo);
        const volScalarField generation0(generation);

        forAll(owner, facei)
        {
            const label own = owner[facei];
            const label nbr = neighbour[facei];

            if (mag(alpha[own] - alpha[nbr]) > alphaDiff)
            {
                if
                (
                    (alpha[nbr] < alpha[own])
                 && (alphaInfo[nbr] < alphaInfo0[own])
                 && (generation[nbr] >= generation0[own])
                )
                {
                    field[nbr] = field0[own];
                    alphaInfo[nbr] = alphaInfo0[own];
                    infoLocation.ref()[own] = 1;
                    infoLocation.ref()[nbr] = 1;
                    generation[nbr] = generation0[own] + 1;
                }
                else if
                (
                    (alpha[own] < alpha[nbr])
                 && (alphaInfo[own] < alphaInfo0[nbr])
                 && (generation[own] >= generation0[nbr])
                )
                {
                    field[own] = field0[nbr];
                    alphaInfo[own] = alphaInfo0[nbr];
                    infoLocation.ref()[own] = 1;
                    infoLocation.ref()[nbr] = 1;
                    generation[own] = generation0[nbr] + 1;
                }
            }
        }
    }

    return infoLocation;
}


// ************************************************************************* //
