/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "volFields.H"
#include "surfaceFields.H"

// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

template<class Type>
bool Foam::functionObjects::deviation::calcDeviation()
{
    typedef VolField<Type> VolFieldType;
    typedef SurfaceField<Type> SurfaceFieldType;

    if (foundObject<VolFieldType>(fieldName_))
    {
        store
        (
            referenceFieldName_,
            tmp<VolFieldType>
            (
                new VolFieldType
                (
                    IOobject
                    (
                        referenceFieldName_,
                        mesh_.time().name(),
                        mesh_,
                        IOobject::MUST_READ,
                        IOobject::AUTO_WRITE
                    ),
                    mesh_
                )
            )
        );

        store
        (
            resultName_,
            lookupObject<VolFieldType>(fieldName_)
          - lookupObject<VolFieldType>(referenceFieldName_)
        );

        resultMaxAbsDev_ =
            max
            (
                mag(gMin(lookupObject<VolFieldType>(resultName_))),
                mag(gMax(lookupObject<VolFieldType>(resultName_)))
            );

        if (foundObject<VolFieldType>(resultName_))
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    else if (foundObject<SurfaceFieldType>(fieldName_))
    {
        store
        (
            referenceFieldName_,
            tmp<SurfaceFieldType>
            (
                new SurfaceFieldType
                (
                    IOobject
                    (
                        referenceFieldName_,
                        mesh_.time().name(),
                        mesh_,
                        IOobject::MUST_READ,
                        IOobject::AUTO_WRITE
                    ),
                    mesh_
                )
            )
        );

        store
        (
            resultName_,
            lookupObject<SurfaceFieldType>(fieldName_)
          - lookupObject<SurfaceFieldType>(referenceFieldName_)
        );

        resultMaxAbsDev_ =
            max
            (
                mag(gMin(lookupObject<SurfaceFieldType>(resultName_))),
                mag(gMax(lookupObject<SurfaceFieldType>(resultName_)))
            );

        if (foundObject<SurfaceFieldType>(resultName_))
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    else
    {
        return false;
    }
}


// ************************************************************************* //
