/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | Multiphase Code Repository by HZDR
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | License: GPL-3.0-or-later
  ==  == ====== ====   ==  ==  |
-------------------------------------------------------------------------------
License
    This file is part of the Multiphase Code Repository by HZDR.

    Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
    Website: https://hzdr.de

    Copyright (C) 2023 by Technische Universitaet Darmstadt,
    Website: https://www.tu-darmstadt.de

    Copyright (C) 2023 by Technische Universitaet Muenchen,
    Website: https://www.tum.de

    Multiphase Code Repository by HZDR is based on the free software for
    computational fluid dynamics (CFD) from the OpenFOAM Foundation.
    Copyright (C) 2023 by OpenFOAM Foundation, Website: https://openfoam.org

    If you are interested in which files are original OpenFOAM Foundation
    files, which OpenFOAM Foundation files were modified, and which files were
    newly created, see FILES.md.

    Multiphase Code Repository by HZDR is free software: you can redistribute
    it and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    Multiphase Code Repository by HZDR is distributed in the hope that it will
    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
    Public License for more details.

    You should have received a copy of the GNU General Public License along
    with the Multiphase Code Repository by HZDR. If not, see
    <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "phaseStructureProperties.H"
#include "volFields.H"
#include "uniformDimensionedFields.H"

// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //

template<class Type>
void Foam::functionObjects::phaseStructureProperties::registerDimensionedObject
(
    const word name,
    const dimensioned<Type>& obj
) const
{
    const word completeName(IOobject::groupName(name, phaseName_));

    if (foundObject<UniformDimensionedField<Type>>(completeName))
    {
        UniformDimensionedField<Type>& regObj =
            obr_.lookupObjectRef<UniformDimensionedField<Type>>(completeName);

        regObj = obj;
    }
    else
    {
        obr_.store
        (
            new UniformDimensionedField<Type>
            (
                IOobject
                (
                    completeName,
                    obr_.time().name(),
                    obr_,
                    IOobject::NO_READ,
                    IOobject::NO_WRITE
                ),
                obj
            )
        );
    }
}


// * * * * * * * * * * * * Protected Member Functions  * * * * * * * * * * * //

template<class Type>
void Foam::functionObjects::phaseStructureProperties::combineFields
(
    Field<Type>& field
)
{
    List<Field<Type>> allValues(Pstream::nProcs());

    allValues[Pstream::myProcNo()] = field;

    Pstream::gatherList(allValues);

    if (Pstream::master())
    {
        field =
            ListListOps::combine<Field<Type>>
            (
                allValues,
                accessOp<Field<Type>>()
            );
    }
}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //


template<class Type>
Foam::tmp<Foam::Field<Type>>
Foam::functionObjects::phaseStructureProperties::filterField
(
    const Field<Type>& field
) const
{
    return tmp<Field<Type>>(new Field<Type>(field, cells()));
}


// ************************************************************************* //
